@@ -35,6 +35,9 @@ def glymurrc_fname():
         fname = os.path.join(confdir, 'glymurrc')
         if os.path.exists(fname):
             return fname
+        else:
+            msg = "Configuration directory '{0}' does not exist.".format(fname)
+            warnings.warn(msg)
 
     # didn't find a configuration file.
     return None
@@ -67,13 +70,6 @@ def load_openjpeg(libopenjpeg_path):
     except OSError:
         openjpeg_lib = None
 
-    if openjpeg_lib is not None:
-        # Must be at least 1.5.0
-        openjpeg_lib.opj_version.restype = ctypes.c_char_p
-        version = openjpeg_lib.opj_version().decode('utf-8')
-        _, minor, _ = version.split('.')
-        if minor != '5':
-            openjpeg_lib = None
     return openjpeg_lib
 
 
@@ -140,7 +136,6 @@ def get_configdir():
     Default is $HOME/.config/glymur.  You can override this with the
     XDG_CONFIG_HOME environment variable.
     """
-
     if 'XDG_CONFIG_HOME' in os.environ:
         return os.path.join(os.environ['XDG_CONFIG_HOME'], 'glymur')
 
