@@ -1,9 +1,11 @@
 from .test_callbacks import TestCallbacks as callbacks
 from .test_codestream import TestCodestream as codestream
+from .test_config import TestSuite as config
 from .test_jp2k import TestJp2k as jp2k
 from .test_icc import TestICC as icc
 from .test_printing import TestPrinting as printing
 from .test_opj_suite import TestSuite as suite
+from .test_opj_suite import TestSuiteDump as suitedump
 from .test_opj_suite_write import TestSuiteWrite as suitew
 from .test_opj_suite_neg import TestSuiteNegative as suiteneg
 from .test_jp2box import TestJp2Boxes as box
